==> homesitemaker-v0.4.1.tar.gz: homesitemaker/includes/login.php <==
<?php

/*
Home Site Maker, the websites factory.
Copyright (C) 2004, 2005 Marcos Martinez Jimenez

This file is part of Home Site Maker.

    Home Site Maker is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    Home Site Maker is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with Home Site Maker; see the file COPYING. If not, write to the Free Software
    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA


Marcos Martinez Jimenez
marcos@assl-site.net
http://homesitemaker.no-ip.org
Francesc Llunell n 1 4 5, Esplugues de Llobregat, 08950 Barcelona, Spain
*/


include ("includes/languages/".$LANGUAGE."/homesite-includes-login.php");

// We get it the date from form 

if (isset($_GET['login'])) {$login=$_GET['login'];} //without --> else {$login="";}
if (isset($_POST['nick'])) {$login=$_POST['nick'];} //without --> else {$login="";}
if (isset($_POST['password'])) {$password=crypt($_POST['password'],'zzxzv');} //without --> else {$password="";}
if (isset($_GET['top_tab'])) {$top_tab=$_GET['top_tab'];} else {$top_tab="1";}
if (isset($_GET['section_type'])) {$section_type=$_GET['section_type'];} else {$section_type="1";}

$auth="no";

if (!empty($login) && !empty($password))
   {
   include ("config_site.php");
   include ("db_connect.php");
   $consulta=mysql_query("SELECT nick, password, level FROM users WHERE nick='$login'",$db);
   $datos_form=mysql_fetch_array($consulta);
   if ($datos_form['nick']==$login && $datos_form['password']==$password)
      {
      echo "<td width=\"100%\" bgcolor=$COLOR2 align=\"center\">\n";
      echo "<span class=\"text2\">$GBL006 <b>".$datos_form["nick"]."</b>!<br><br></span>\n";
      echo "<span class=\"text1\">$GBL007</span>\n";
      echo "<br><span class=\"text1\"><a href=\"index.php?top_tab=$top_tab&section_type=$section_type".
           "&num=$num\">$GBL008</span></td></a>";
      $auth="ok";
      } else {
             $datos_form['nick']="";
             $datos_form['password']="";
             }
   }// if not empty


if (($id_session[num]!=$num && $auth=="no") || (!isset($id_session[num]) && $auth=="no"))
   {
   echo "<td width=\"100%\" bgcolor=$COLOR2 class=\"text1\" align=\"center\">\n";
   echo "$TITLE $GBL001<br><br>\n";
   echo "<form method=\"post\" action=\"index.php?top_tab=$top_tab&section_type=$section_type&num=$num\">\n";
   echo "$GBL002<br><input type=\"text\" name=\"nick\" size=\"8\"><br><br>\n";
   echo "$GBL003<br><input type=\"password\" name=\"password\" size=\"8\"><br><br>\n";
   echo "<input type=\"submit\" value=\"$GBL005\">\n";
   echo "</form>\n";
   echo "<br><div class=\"link1\"><a href=\"index.php?top_tab=5&section_type=1&user_section=3\">$GBL004</a></div>";
   echo "</td>\n";
   } else if ($id_session[num]==$num && isset($id_session[num]))
             {
             echo "<td width=\"100%\" bgcolor=$COLOR2 align=\"center\">";
             echo "<span class=\"text1\">$GBL009 <b>$id_session[user]</b></span>";
             echo "<span class=\"text2\"><br><br>$GBL010<br><br></span>";
             echo "<span class=\"link1\"><a href=\"index.php?top_tab=5&section_type=1&user_section=0".
                  "&num=$num\">$GBL011</a></br></span>";
             // We need to know where the pending items are.
             include ("includes/db_connect.php");
             $news_query=mysql_query("SELECT section FROM info WHERE status='1'", $db);
             $albums_query=mysql_query("SELECT section FROM album WHERE status='0'", $db);
             $pending_news=mysql_num_rows($news_query);
             $pending_albums=mysql_num_rows($albums_query);
             $pending_items=$pending_news+$pending_albums;
             $section_news=mysql_fetch_array($news_query);
             $section_albums=mysql_fetch_array($albums_query);
             $news_section_number=trim($section_news[section],"TAB_");
             $albums_section_number=trim($section_albums[section],"TAB_");
             if ($pending_items>0)
                {
                if ($pending_news>0)
                   {
                   echo "<span class=\"link1\"><a href=\"index.php?top_tab=$news_section_number[0]".
                        "&section_type=$news_section_number[1]&num=$num&task=pending\">$GBL012 ($pending_news)</a></br></span>";
                   }
                if ($pending_albums>0)
                   {
                   echo "<span class=\"link1\"><a href=\"index.php?top_tab=$albums_section_number[0]&section_type=".
                        "$albums_section_number[1]&num=$num&task=pending\">$GBL013 ($pending_albums)</a></br></span>";
                   }
                } else echo "<span class=\"text1\">$GBL014 ($pending_items)</a></br></span>";
             echo "<span class=\"link1\"><a href=\"index.php?top_tab=5&section_type=4".
                  "&num=$num\">$GBL015</a></br></span>";
             echo "<span class=\"link1\"><a href=\"index.php?top_tab=1&section_type=$section_type&logout=yes\"><br>$GBL016</a></span></td>";
             }
?>

==> homesitemaker-v0.4.4.tar.gz: homesitemaker/includes/login.php <==
<?php

/*
Home Site Maker, the websites factory.
Copyright (C) 2004, 2005 Marcos Martinez Jimenez

This file is part of Home Site Maker.

    Home Site Maker is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    Home Site Maker is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with Home Site Maker; see the file COPYING. If not, write to the Free Software
    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA


Marcos Martinez Jimenez
marcos@assl-site.net
http://homesitemaker.no-ip.org
Francesc Llunell n 1 4 5, Esplugues de Llobregat, 08950 Barcelona, Spain
*/


include ("includes/languages/".$LANGUAGE."/homesite-includes-login.php");
include ("images/skins/".$SKIN."/".$SKIN.".php");
$fondo=$COLOR;
if ($COLOR=="B" || $COLOR=="Y" || $COLOR=="M" || $COLOR=="G")
   {
   if ($COLOR=="B") $fondo=$COLOR1;
   if ($COLOR=="Y") $fondo=$COLOR2;
   if ($COLOR=="M") $fondo=$COLOR3;
   if ($COLOR=="G") $fondo=$COLOR4;
   }

// We get it the date from form 

if (isset($_GET['login'])) {$login=$_GET['login'];} //without --> else {$login="";}
if (isset($_POST['nick'])) {$login=$_POST['nick'];} //without --> else {$login="";}
if (isset($_POST['password'])) {$password=crypt($_POST['password'],'zzxzv');} //without --> else {$password="";}
if (isset($_GET['top_tab'])) {$top_tab=$_GET['top_tab'];} else {$top_tab="1";}
if (isset($_GET['section_type'])) {$section_type=$_GET['section_type'];} else {$section_type="1";}

$auth="no";

if (!empty($login) && !empty($password))
   {
   include ("config_site.php");
   include ("db_connect.php");
   $consulta=mysql_query("SELECT nick, password, level FROM users WHERE nick='$login'",$db);
   $datos_form=mysql_fetch_array($consulta);
   if ($datos_form['nick']==$login && $datos_form['password']==$password)
      {
      echo "<td width=\"100%\" bgcolor=$fondo align=\"center\">\n";
      echo "<span class=\"text2\">$GBL006 <b>".$datos_form["nick"]."</b>!<br><br></span>\n";
      echo "<span class=\"text1\">$GBL007</span>\n";
      echo "<br><span class=\"text1\"><a href=\"index.php?top_tab=$top_tab&section_type=$section_type".
           "&num=$num\">$GBL008</span></td></a>";
      $auth="ok";
      } else {
             $datos_form['nick']="";
             $datos_form['password']="";
             }
   }// if not empty


if (($id_session[num]!=$num && $auth=="no") || (!isset($id_session[num]) && $auth=="no"))
   {
   echo "<td width=\"100%\" bgcolor=$fondo class=\"text1\" align=\"center\">\n";
   echo "$TITLE $GBL001<br><br>\n";
   echo "<form method=\"post\" action=\"index.php?top_tab=$top_tab&section_type=$section_type&num=$num\">\n";
   echo "$GBL002<br><input type=\"text\" name=\"nick\" size=\"8\"><br><br>\n";
   echo "$GBL003<br><input type=\"password\" name=\"password\" size=\"8\"><br><br>\n";
   echo "<input type=\"submit\" value=\"$GBL005\">\n";
   echo "</form>\n";
   echo "<br><div class=\"link1\"><a href=\"index.php?top_tab=5&section_type=1&user_section=3\">$GBL004</a></div>";
   echo "</td>\n";
   } else if ($id_session[num]==$num && isset($id_session[num]))
             {
             echo "<td width=\"100%\" bgcolor=$fondo align=\"center\">";
             echo "<span class=\"text1\">$GBL009 <b>$id_session[user]</b></span>";
             echo "<span class=\"text2\"><br><br>$GBL010<br><br></span>";
             echo "<span class=\"link1\"><a href=\"index.php?top_tab=5&section_type=1&user_section=0".
                  "&num=$num\">$GBL011</a></br></span>";
             // We need to know where the pending items are.
             include ("includes/db_connect.php");
             $news_query=mysql_query("SELECT section FROM info WHERE status='1'", $db);
             $albums_query=mysql_query("SELECT section FROM album WHERE status='0'", $db);
             $pending_news=mysql_num_rows($news_query);
             $pending_albums=mysql_num_rows($albums_query);
             $pending_items=$pending_news+$pending_albums;
             $section_news=mysql_fetch_array($news_query);
             $section_albums=mysql_fetch_array($albums_query);
             $news_section_number=trim($section_news[section],"TAB_");
             $albums_section_number=trim($section_albums[section],"TAB_");
             if ($pending_items>0)
                {
                if ($pending_news>0)
                   {
                   echo "<span class=\"link1\"><a href=\"index.php?top_tab=$news_section_number[0]".
                        "&section_type=$news_section_number[1]&num=$num&task=pending\">$GBL012 ($pending_news)</a></br></span>";
                   }
                if ($pending_albums>0)
                   {
                   echo "<span class=\"link1\"><a href=\"index.php?top_tab=$albums_section_number[0]&section_type=".
                        "$albums_section_number[1]&num=$num&task=pending\">$GBL013 ($pending_albums)</a></br></span>";
                   }
                } else echo "<span class=\"text1\">$GBL014 ($pending_items)</a></br></span>";
             echo "<span class=\"link1\"><a href=\"index.php?top_tab=5&section_type=4".
                  "&num=$num\">$GBL015</a></br></span>";
             echo "<span class=\"link1\"><a href=\"index.php?top_tab=1&section_type=$section_type&logout=yes\"><br>$GBL016</a></span></td>";
             }
?>
